@@ -7,6 +7,8 @@ import cv2
 from .digit_recognizer_utils import correct_orientation,\
     preprocess_ROI, add_padding_and_clip, variance_of_laplacian,\
     cleanup_ticket_number
+from uuid import uuid4
+import shutil
 
 
 class DigitRecognizer(MLModel):
@@ -30,8 +32,63 @@ class DigitRecognizer(MLModel):
         self.lang = '{mod_name}_latest'.format(mod_name=self.model_name)
 
     def train(self):
-        print('yay, I am training')
-        time.sleep(60)
+        # Change to tesstrain directory if exists
+        if os.path.isdir("tesstrain"):
+            orig_path = os.getcwd()
+            os.chdir(orig_path+'/tesstrain/')
+
+        # Train data directory
+        train_data_dir = orig_path+'/'+self.config['train_data_dir']
+
+        # Start training
+        os.system('make training MODEL_NAME={model_name} \
+            DATA_DIR={train_data_dir} \
+            START_MODEL=eng PSM={psm}\
+            TESSDATA=/usr/local/share/tessdata'.format(
+                model_name=self.model_name,
+                train_data_dir=train_data_dir,
+                psm=self.config['psm']))
+
+        # Change back to original working directory
+        os.chdir(orig_path)
+
+        # Rename digits.trainedata
+        new_params_id = uuid4().hex
+        old_filename = '{model_name}.traineddata'.format(
+            model_name=self.model_name)
+        new_filename = '{model_name}_{new_params_id}.traineddata'.format(
+            model_name=self.model_name,
+            new_params_id=new_params_id)
+        os.rename('{model_dir}/{old_filename}'.format(
+                model_dir=train_data_dir,
+                old_filename=old_filename),  # Old filepath/filename
+            '{model_dir}/{new_filename}'.format(
+                model_dir=train_data_dir,
+                new_filename=new_filename)  # New filepath/filename
+            )
+
+        # Upload new model to S3
+        self._upload_file(
+            self._get_s3_client(), train_data_dir+'/'+new_filename,
+            os.environ['S3_MODEL_BUCKET'], new_filename)
+
+        # Update manifest on S3
+        file_name = 'manifest_{mod_name}.{ext}'.format(
+            mod_name=self.model_name, ext='txt')
+
+        save_to = self.config['model_dir']+file_name
+        self._save_new_manifest(new_params_id, save_to)
+
+        self._upload_file(
+            self._get_s3_client(), save_to,
+            os.environ['S3_MODEL_BUCKET'], file_name)
+
+        # Remove training generated files/folders
+        os.remove(save_to)
+        os.remove(train_data_dir+'/'+new_filename)
+        os.remove(train_data_dir+'/'+'radical-stroke.txt')
+        shutil.rmtree(train_data_dir+'/'+'eng')
+        shutil.rmtree(train_data_dir+'/'+self.model.name)
 
     def predict(self, image_pil, predictions):
         start = time.time()
