@@ -6,8 +6,6 @@ import numpy as np
 from uuid import uuid4
 from tensorflow.keras import layers
 from tensorflow.keras.models import Sequential
-from . import logger
-my_logger = logger.logger('ocr')
 
 
 class DumpTicketClassifier(MLModel):
@@ -61,7 +59,6 @@ class DumpTicketClassifier(MLModel):
         os.remove(weights_path)
 
     def train(self):
-        my_logger.info('I am training')
         # Gather training params from config file
         img_height = self.config['model_image_height']
         img_width = self.config['model_image_width']
@@ -93,7 +90,6 @@ class DumpTicketClassifier(MLModel):
         file_name = '{mod_name}_{model_id}.{ext}'.format(
                 mod_name=self.model_name, model_id=new_params_id, ext='h5')
         new_weights_path = self.config['model_dir']+file_name
-        my_logger.info('New weights will be saved as '+str(new_weights_path))
 
         model_checkpoint_callback = tf.keras.callbacks.ModelCheckpoint(
                 filepath=new_weights_path,
@@ -109,7 +105,6 @@ class DumpTicketClassifier(MLModel):
             self.config['model_image_height'],  # Input image height
             self.config['model_image_width'])  # Input image width
         weights_path = self._get_objects_from_s3(self.config['model_dir'])
-        my_logger.info('Initial weights loaded from '+str(weights_path))
         # Load weights in model
         self.model.load_weights(weights_path)
 
