@@ -12,7 +12,8 @@ class MLModel(metaclass=ABCMeta):
         self.config = self._get_config(config_version)
         self.do_not_update = do_not_update
         self.model_id = self._get_model_id(model_id)
-        self.load_model()
+        if not self.do_not_update:
+            self.load_model()
         self.schedule_model_check()
 
     @staticmethod
@@ -77,7 +78,6 @@ class MLModel(metaclass=ABCMeta):
         if not self.do_not_update:
             scheduler = BackgroundScheduler()
             scheduler.add_job(self._load_if_model_updated, 'interval', minutes=5)
-            scheduler.add_job(self.train, 'interval', minutes=10)
             scheduler.start()
 
     @abstractmethod
